@@ -75,8 +75,8 @@ class RDSDataServiceClient(BaseClient):
         secretArn: str,
         sql: str,
         database: str = ...,
-        parameterSets: Sequence[Sequence["SqlParameterTypeDef"]] = ...,
         schema: str = ...,
+        parameterSets: Sequence[Sequence[SqlParameterTypeDef]] = ...,
         transactionId: str = ...
     ) -> BatchExecuteStatementResponseTypeDef:
         """
@@ -104,6 +104,14 @@ class RDSDataServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rds-data.html#RDSDataService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rds_data/client/#close)
+        """
+
     def commit_transaction(
         self, *, resourceArn: str, secretArn: str, transactionId: str
     ) -> CommitTransactionResponseTypeDef:
@@ -118,8 +126,8 @@ class RDSDataServiceClient(BaseClient):
     def execute_sql(
         self,
         *,
-        awsSecretStoreArn: str,
         dbClusterOrInstanceArn: str,
+        awsSecretStoreArn: str,
         sqlStatements: str,
         database: str = ...,
         schema: str = ...
@@ -137,14 +145,14 @@ class RDSDataServiceClient(BaseClient):
         resourceArn: str,
         secretArn: str,
         sql: str,
-        continueAfterTimeout: bool = ...,
         database: str = ...,
-        formatRecordsAs: RecordsFormatTypeType = ...,
-        includeResultMetadata: bool = ...,
-        parameters: Sequence["SqlParameterTypeDef"] = ...,
-        resultSetOptions: "ResultSetOptionsTypeDef" = ...,
         schema: str = ...,
-        transactionId: str = ...
+        parameters: Sequence[SqlParameterTypeDef] = ...,
+        transactionId: str = ...,
+        includeResultMetadata: bool = ...,
+        continueAfterTimeout: bool = ...,
+        resultSetOptions: ResultSetOptionsTypeDef = ...,
+        formatRecordsAs: RecordsFormatTypeType = ...
     ) -> ExecuteStatementResponseTypeDef:
         """
         Runs a SQL statement against a database.
